@@ -21,8 +21,8 @@
 
 /*
  * Adapted from Nautilus shell-search-provider
- * 
- * Authors: 
+ *
+ * Authors:
  * Original code : Cosimo Cecchi <cosimoc@gnome.org>
  * Bijiben : Pierre-Yves Luyten <py@luyten.fr>
  *
@@ -83,7 +83,7 @@ bjb_perform_query (BijibenShellSearchProviderApp *self, gchar * query )
   return result ;
 }
 
-GList *
+static GList *
 biji_get_notes_with_strings (BijibenShellSearchProviderApp *self, gchar **needles)
 {
   gint parser;
@@ -205,12 +205,9 @@ get_note_icon (BijibenShellSearchProviderApp *self,
   GVariant *variant;
   GIcon *gicon;
   gint scale_factor;
-  GdkScreen *screen;
   BijiItem *item;
 
-  screen = gdk_screen_get_default ();
-  scale_factor = gdk_screen_get_monitor_scale_factor (screen,
-                                                      gdk_screen_get_primary_monitor (screen));
+  scale_factor = gdk_monitor_get_scale_factor (gdk_display_get_primary_monitor (gdk_display_get_default ()));
 
   gicon = NULL;
   item = biji_manager_get_item_at_path (self->manager, note__nie_url);
@@ -283,7 +280,7 @@ add_single_note_meta (BijibenShellSearchProviderApp *self,
 
     g_variant_builder_close (results);
   }
- 
+
   g_object_unref (cursor);
 }
 
@@ -325,7 +322,7 @@ handle_activate_result (BijibenShellSearchProvider2  *skeleton,
 
   g_application_hold (user_data);
 
-  app = G_APP_INFO (g_desktop_app_info_new ("bijiben.desktop"));
+  app = G_APP_INFO (g_desktop_app_info_new ("org.gnome.bijiben.desktop"));
 
   context = gdk_display_get_app_launch_context (gdk_display_get_default ());
   gdk_app_launch_context_set_timestamp (context, timestamp);
