@@ -17,8 +17,7 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef _BJB_CONTROLLER_H_
-#define _BJB_CONTROLLER_H_
+#pragma once
 
 #include <glib-object.h>
 #include <libbiji/libbiji.h>
@@ -68,6 +67,3 @@ gboolean bjb_controller_get_remaining_items (BjbController *self);
 
 
 G_END_DECLS
-
-
-#endif /* _BJB_CONTROLLER_H_ */
