@@ -15,13 +15,9 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef _BJB_SHARE_H
-#define _BJB_SHARE_H
+#pragma once
 
 #include <libbiji/libbiji.h>
 #include <gtk/gtk.h>
 
 gboolean on_email_note_callback(GtkWidget *widget, BijiNoteObj *note) ;
- 
-#endif
-
