@@ -27,25 +27,20 @@
 #include "biji-item.h"
 #include "biji-own-cloud-note.h"
 #include "biji-own-cloud-provider.h"
-#include "../biji-timeout.h"
 #include "../serializer/biji-lazy-serializer.h"
 
-
-
-struct BijiOwnCloudNotePrivate_
+struct _BijiOwnCloudNote
 {
+  BijiNoteObj           parent_instance;
   BijiOwnCloudProvider *prov;
   BijiNoteID *id;
 
-  BijiTimeout           *timeout;
-
-
   GFile *location;
   gchar *basename;
   GCancellable *cancellable; //TODO cancel write to file
 
   /* Ensure not to save while application quits & unneeded. */
-  gboolean needs_save;
+  gboolean needs_rename;
 };
 
 
@@ -63,7 +58,7 @@ ocloud_note_get_place (BijiItem *local)
   g_return_val_if_fail (BIJI_IS_OWN_CLOUD_NOTE (local), NULL);
 
   self = BIJI_OWN_CLOUD_NOTE (local);
-  info = biji_provider_get_info (BIJI_PROVIDER (self->priv->prov));
+  info = biji_provider_get_info (BIJI_PROVIDER (self->prov));
 
   return info->name;
 }
@@ -88,7 +83,7 @@ ocloud_note_get_html (BijiNoteObj *note)
   err = NULL;
   self = BIJI_OWN_CLOUD_NOTE (note);
 
-  if (g_file_load_contents (self->priv->location, NULL, &content, 0, NULL, &err))
+  if (g_file_load_contents (self->location, NULL, &content, 0, NULL, &err))
   {
     html = html_from_plain_text (content);
     g_free (content);
@@ -126,24 +121,23 @@ ocloud_note_ensure_ressource (BijiNoteObj *note)
   BijiInfoSet *info;
   BijiItem *item;
   BijiOwnCloudNote *ocnote;
-  GFile *file;
-  GFileInfo *file_info;
+  g_autoptr(GFileInfo) file_info = NULL;
   const BijiProviderInfo *provider;
 
   g_return_if_fail (BIJI_IS_OWN_CLOUD_NOTE (note));
-  g_return_if_fail (G_IS_FILE (BIJI_OWN_CLOUD_NOTE (note)->priv->location));
+  g_return_if_fail (G_IS_FILE (BIJI_OWN_CLOUD_NOTE (note)->location));
 
   item = BIJI_ITEM (note);
   ocnote = BIJI_OWN_CLOUD_NOTE (note);
-  file = ocnote->priv->location;
-  file_info = g_file_query_info (file, "time::modified", G_FILE_QUERY_INFO_NONE, NULL, NULL);
-  provider = biji_provider_get_info (BIJI_PROVIDER (ocnote->priv->prov));
+  file_info = g_file_query_info (ocnote->location, G_FILE_ATTRIBUTE_TIME_MODIFIED,
+                                 G_FILE_QUERY_INFO_NONE, NULL, NULL);
+  provider = biji_provider_get_info (BIJI_PROVIDER (ocnote->prov));
 
   info = biji_info_set_new ();
   info->url = (gchar*) biji_item_get_uuid (item);
   info->title = (gchar*) biji_item_get_title (item);
   info->content = (gchar*) biji_note_obj_get_raw_text (note);
-  info->mtime = g_file_info_get_attribute_uint64 (file_info, "time::modified");
+  info->mtime = g_file_info_get_attribute_uint64 (file_info, G_FILE_ATTRIBUTE_TIME_MODIFIED);
   info->created = biji_note_obj_get_create_date (note);
   info->datasource_urn = g_strdup (provider->datasource);
 
@@ -151,118 +145,79 @@ ocloud_note_ensure_ressource (BijiNoteObj *note)
                                             info);
 }
 
-
-/* TODO: propagate error if any
- * through generic provider -> manager */
 static void
-on_content_replaced  (GObject *source_object,
-                      GAsyncResult *res,
-                      gpointer user_data)
+ocloud_note_set_id (BijiOwnCloudNote *self)
 {
-  GError *error = NULL;
+  g_autofree gchar *key = NULL;
 
-  if (!g_file_replace_contents_finish (G_FILE (source_object),
-                                       res,
-                                       NULL,  //etag
-                                       &error))
-  {
-    if (error)
-    {
-      g_warning ("ownCloud note not saved. %s", error->message);
-      g_error_free (error);
-    }
-  }
-
-
-  else
-  {
-    ocloud_note_ensure_ressource (user_data);
-  }
+  key = g_strdup_printf ("%s/%s",
+                         biji_own_cloud_provider_get_readable_path (self->prov),
+                         self->basename);
+  g_object_set (self->id, "path", key, NULL);
 }
 
-
-
-
-
 static void
 ocloud_note_save (BijiNoteObj *note)
 {
   BijiOwnCloudNote *self;
-  GString *str;
+  GFile *folder, *tmp_file;
+  const gchar *str;
+  g_autoptr(GError) error = NULL;
+  GFileOutputStream *new_file;
 
   g_return_if_fail (BIJI_IS_OWN_CLOUD_NOTE (note));
   self = BIJI_OWN_CLOUD_NOTE (note);
-  str = g_string_new (biji_note_obj_get_raw_text (note));
+  str = biji_note_obj_get_raw_text (note);
 
+  /* create note file if it doesn't exist */
+  if (self->location == NULL || !g_file_query_exists (self->location, NULL))
+    {
+      folder = biji_own_cloud_provider_get_folder (self->prov);
+      if (self->location)
+        g_object_unref (self->location);
+      self->location = g_file_get_child (folder, self->basename);
+      new_file = g_file_create (self->location, G_FILE_CREATE_NONE,
+                                NULL, &error);
+      if (error)
+        {
+          g_warning ("ownCloud note not created. %s", error->message);
+          return;
+        }
+      g_clear_object (&new_file);
+      self->needs_rename = FALSE;
+      ocloud_note_set_id (self);
+    }
+  /* if file exists and its title was changed */
+  else if (self->needs_rename)
+    {
+      tmp_file = self->location;
+      self->location = g_file_set_display_name (self->location, self->basename,
+                                                NULL, &error);
+      if (error)
+        {
+          g_warning ("ownCloud note not renamed. %s", error->message);
+          self->location = tmp_file;
+          return;
+        }
+      g_clear_object (&tmp_file);
+      self->needs_rename = FALSE;
+      ocloud_note_set_id (self);
+    }
 
   /* backup would fail for some reason.
    * gfilemove for workaround? */
-  g_file_replace_contents_async  (
-      self->priv->location,
-      str->str,
-      str->len,
-      NULL,   // etag
-      FALSE,  //backup
-      G_FILE_CREATE_REPLACE_DESTINATION,
-      self->priv->cancellable,
-      on_content_replaced,
-      self);
+  if (!g_file_replace_contents (self->location, str, strlen(str), NULL, FALSE,
+                                G_FILE_CREATE_REPLACE_DESTINATION, NULL,
+                                self->cancellable, &error))
+    {
+      g_file_get_path (self->location);
+      g_warning ("ownCloud note not updated. %s", error->message);
+      return;
+    }
 
-
-  g_string_free (str, FALSE);
+  ocloud_note_ensure_ressource (BIJI_NOTE_OBJ (self));
 }
 
-
-
-
-
-
-
-
-/* Rename the file
- * when note title change
- * Also handle new notes being populated
- * the noteID still keep some path, which we will remove */
-
-static void
-create_new_file (BijiOwnCloudNote *self, const gchar *basename)
-{
-  GFile *folder;
-  BijiNoteObj *note;
-  gchar *key;
-
-  note = BIJI_NOTE_OBJ (self);
-  folder = biji_own_cloud_provider_get_folder (self->priv->prov);
-
-  /* TODO just free old location before, but check for no mistake */
-
-  self->priv->location = g_file_get_child (folder, basename);
-  key = g_strdup_printf (
-               "%s/%s",
-               biji_own_cloud_provider_get_readable_path (self->priv->prov),
-               basename);
-  g_object_set (self->priv->id, "path", key, NULL);
-
-  g_file_create (self->priv->location, G_FILE_CREATE_NONE, NULL, NULL);
-  ocloud_note_save (note);
-  ocloud_note_ensure_ressource (note);
-
-  g_free (key);
-}
-
-
-/* When the title is stable, handle io */
-static void
-on_timeout (BijiOwnCloudNote *self)
-{
-  if (!self->priv->needs_save)
-    return;
-
-  self->priv->needs_save = FALSE;
-  create_new_file (self, self->priv->basename);
-}
-
-
 static void
 on_title_change                     (BijiOwnCloudNote *self)
 {
@@ -270,19 +225,10 @@ on_title_change                     (BijiOwnCloudNote *self)
 
   g_return_if_fail (BIJI_IS_OWN_CLOUD_NOTE (self));
 
-  g_free (self->priv->basename);
-  new_title = biji_note_id_get_title (self->priv->id);
-  self->priv->basename = g_strdup_printf ("%s.txt", new_title);
-  self->priv->needs_save = TRUE;
-
-
-  g_file_delete_async (self->priv->location,
-                       G_PRIORITY_LOW,
-                       NULL,
-                       NULL,
-                       NULL);
-
-  biji_timeout_reset (self->priv->timeout, 3000);
+  g_free (self->basename);
+  new_title = biji_note_id_get_title (self->id);
+  self->basename = g_strdup_printf ("%s.txt", new_title);
+  self->needs_rename = TRUE;
 }
 
 
@@ -298,9 +244,8 @@ biji_own_cloud_note_finalize (GObject *object)
 
   self = BIJI_OWN_CLOUD_NOTE (object);
 
-  g_object_unref (self->priv->location);
-  g_object_unref (self->priv->timeout);
-  g_object_unref (self->priv->cancellable);
+  g_object_unref (self->location);
+  g_object_unref (self->cancellable);
 
   G_OBJECT_CLASS (biji_own_cloud_note_parent_class)->finalize (object);
 }
@@ -318,14 +263,7 @@ biji_own_cloud_note_constructed (GObject *object)
 static void
 biji_own_cloud_note_init (BijiOwnCloudNote *self)
 {
-  self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, BIJI_TYPE_OWN_CLOUD_NOTE, BijiOwnCloudNotePrivate);
-  self->priv->cancellable = g_cancellable_new ();
-  self->priv->id = NULL;
-  self->priv->needs_save = FALSE;
-
-  self->priv->timeout = biji_timeout_new ();
-  g_signal_connect_swapped (self->priv->timeout, "timeout",
-                            G_CALLBACK (on_timeout), self);
+  self->cancellable = g_cancellable_new ();
 }
 
 
@@ -350,14 +288,14 @@ ocloud_note_delete (BijiNoteObj *note)
 
   self = BIJI_OWN_CLOUD_NOTE (note);
   biji_note_delete_from_tracker (BIJI_NOTE_OBJ (self));
-  return g_file_delete (self->priv->location, NULL, NULL);
+  return g_file_delete (self->location, NULL, NULL);
 }
 
 
 static gchar *
 ocloud_note_get_basename (BijiNoteObj *note)
 {
-  return BIJI_OWN_CLOUD_NOTE (note)->priv->basename;
+  return BIJI_OWN_CLOUD_NOTE (note)->basename;
 }
 
 
@@ -386,8 +324,6 @@ biji_own_cloud_note_class_init (BijiOwnCloudNoteClass *klass)
   note_class->can_format = note_no;
   note_class->archive = ocloud_note_delete;
   note_class->is_trashed = note_no;
-
-  g_type_class_add_private ((gpointer)klass, sizeof (BijiOwnCloudNotePrivate));
 }
 
 
@@ -436,19 +372,19 @@ BijiNoteObj        *biji_own_cloud_note_new_from_info           (BijiOwnCloudPro
                          NULL);
 
   ocloud = BIJI_OWN_CLOUD_NOTE (retval);
-  ocloud->priv->id = id;
-  ocloud->priv->prov = prov;
+  ocloud->id = id;
+  ocloud->prov = prov;
   biji_note_obj_set_create_date (retval, info->created);
   g_signal_connect_swapped (id, "notify::title",
                             G_CALLBACK (on_title_change), retval);
 
 
   if (online)
-    ocloud->priv->location = g_file_new_for_commandline_arg (info->url);
+    ocloud->location = g_file_new_for_commandline_arg (info->url);
   else
-    ocloud->priv->location = g_file_new_for_path (info->url);
+    ocloud->location = g_file_new_for_path (info->url);
 
-  ocloud->priv->basename = g_file_get_basename (ocloud->priv->location);
+  ocloud->basename = g_file_get_basename (ocloud->location);
 
   return retval;
 }
